// calculate product price from area selected.
// product priced per square or linear metre
// V3.01 - Imperial units
// V3.00 - New price override
// V3.03 - Adds perimeter capability
// V3.03 - Adds minimum price
// V3.06 - Drop Downs.  Vat Factor now a variable.
// V3.07 - Additional custom drop-downs, check-boxes or radios that add to price

var prodinfo = new Object();

function CommaFormatted(num){				// Comma format a number.
	var sep = ',';
	num = num.toString().split('').reverse().join('');		// reverse number
	num = num.replace(/(\d\d\d)(?=\d)(?!\d*\.)/g,'$1' + sep);	// add commas
	return num.split('').reverse().join('');			// reverse number back;
}

// called when product loads - saves some useful info		
function saveproductinfo(pid, ProductPriceRaw, MinWidth, MaxWidth, MinLength, MaxLength, SellByExactArea, Sizeunits, WidthName, LengthName, MinPrice, Special){
	prodinfo[pid] = new Object();
	prodinfo[pid].pricepermetre = ProductPriceRaw;
	prodinfo[pid].minwidth = MinWidth;
	prodinfo[pid].maxwidth = MaxWidth;
	prodinfo[pid].minlength = MinLength;
	prodinfo[pid].maxlength = MaxLength;
	prodinfo[pid].sellbyexactarea = SellByExactArea;
	prodinfo[pid].sizeunits = Sizeunits;
	prodinfo[pid].widthname = WidthName;
	prodinfo[pid].lengthname = LengthName;
	prodinfo[pid].minprice = MinPrice;
	prodinfo[pid].special = Special;
}

// main calculation routine - called when sizes change and before add to cart
// checks values entered, looks up price, displays warnings if error, displays price, sets form data, returns true / false
function calcprice(pid){
	var width = document.getElementById('wid_' + pid).value;	// customer entered width
	var length = document.getElementById('len_' + pid).value;	// customer entered length
	var scalefactor;
	var sizeunits = prodinfo[pid].sizeunits;
	var widthname = prodinfo[pid].widthname;
	var lengthname = prodinfo[pid].lengthname;

	switch (sizeunits.toLowerCase()) {
		case 'm'  : scalefactor = 1; 	break;
		case 'cm' : scalefactor = 100;	break;
		case 'mm' : scalefactor = 1000;	break;
		case 'in' : scalefactor = 12;	break;
		case 'ft' : scalefactor = 1;	break;
	}
	var validcount = 0;
	if ( (width != '') &&  ! isNaN(width) )
		{
		if ( width <  prodinfo[pid].minwidth )
			{
			alert(widthname + ' must be more than ' + CommaFormatted(prodinfo[pid].minwidth) + sizeunits);
			}
		else
			{
			validcount++;
			}
		if ( width > prodinfo[pid].maxwidth )
			{
			alert(widthname + ' must be less than ' + CommaFormatted(prodinfo[pid].maxwidth) + sizeunits);
			}
		else
			{
			validcount++;
			}
		}
	if ( (length != '') && ! isNaN(length) )
		{
		if ( length <  prodinfo[pid].minlength )
			{
			alert(lengthname + ' must be more than ' + CommaFormatted(prodinfo[pid].minlength) + sizeunits);
			}
			else
			{
			validcount++;
			}
		if ( length >  prodinfo[pid].maxlength )
			{
			alert(lengthname + ' must be less than ' + CommaFormatted(prodinfo[pid].maxlength) + sizeunits);
			}
		else
			{
			validcount++;
			}
		}
	if ( validcount == 4 )
		{
		switch ( prodinfo[pid].special )	// See if any special features required
			{
			case 1:		// Permiter calculation
				var price = prodinfo[pid].pricepermetre * (length * 2 + width * 2) / scalefactor;	// Perimeter calculation
				break;

			default:	// Original selling by area or length	
				if ( prodinfo[pid].sellbyexactarea )		// by exact area - product priced per square metre
					{
					var price = prodinfo[pid].pricepermetre * (length / scalefactor) * (width / scalefactor);
					}
				else						// by length required - product priced per linear metre
					{
					var price = prodinfo[pid].pricepermetre * length / scalefactor;
					}	
			}

		if ( price < prodinfo[pid].minprice ) price = prodinfo[pid].minprice - 0;	// V302 Enforce minimum price

		var optioninfo = '';
		// additional drop-downs
		var dds = document.getElementsByTagName('select');
		for ( var i=0; i<dds.length; i++ )
			{
			if ( dds[i].getAttribute('class') == 'bpodd_' + pid )
				{
				var selectedOpt = dds[i].options[dds[i].selectedIndex];
				price = price + (selectedOpt.value - 0);
				var optprompt = selectedOpt.getAttribute('data-prompt');
				var optinfo = selectedOpt.getAttribute('data-info');
				var optsuffix = selectedOpt.getAttribute('data-suffix');
				if ( optprompt || optinfo || optsuffix ) optioninfo += '' + (optprompt ? optprompt : '') + '' + (optinfo ? optinfo : '') + '' + (optsuffix ? optsuffix : '');
				}
			}

		// additional radios or checkboxes
		var dds = document.getElementsByTagName('input');
		for ( var i=0; i<dds.length; i++ )
			{
			if ( (dds[i].getAttribute('class') == 'bpodd_' + pid) && dds[i].checked )
				{
				var selectedOpt = dds[i];
				price = price + (selectedOpt.value - 0);
				var optprompt = selectedOpt.getAttribute('data-prompt'); 
				var optinfo = selectedOpt.getAttribute('data-info');
				var optsuffix = selectedOpt.getAttribute('data-suffix');
				if ( optprompt || optinfo || optsuffix ) optioninfo += '' + (optprompt ? optprompt : '') + '' + (optinfo ? optinfo : '') + '' + (optsuffix ? optsuffix : '');
				}
			}

		price = price.toFixed(2);
		
		// price override info for cart. Format price then any number of informative namevaluesuffix separated by 
		// e.g.
		// 12.34:Width;1,200;mm:Length;3,456;mm
		document.getElementById('ovr_' + pid).value = price + '' + widthname + '' + CommaFormatted(width) + '' + sizeunits + '' + lengthname + '' + CommaFormatted(length) + '' + sizeunits + optioninfo;
		// display VAT inclusive if required - NB Actinic bug in TaxTreament prevents us using this
		if ( vatfactor != 1 ) price = (price * vatfactor).toFixed(2);   
		document.getElementById('prc_' + pid).innerHTML = price;  
		return true;
		}
	// something wrong so clear value	
	document.getElementById('prc_' + pid).innerHTML = '';  
	document.getElementById('ovr_' + pid).value = '';  
	return false;  
} 

function checksizes(pid){		// called when form submitted
	return calcprice(pid);
} 

function refreshprices(){		// called on page load.  Refresh any prices.
	for ( pid in prodinfo )
		{
		document.getElementById('wid_' + pid).value = prodinfo[pid].minwidth;
		document.getElementById('len_' + pid).value = prodinfo[pid].minlength;
		calcprice(pid);
		}
}

(typeof(jQuery) != 'undefined') ? $(document).ready(function(){refreshprices()}) : DomReady.ready(function(){refreshprices();});

